Authors
=======

Package Author
--------------
* Jake Vanderplas http://jakevdp.github.com

Package Maintainer
------------------
* Brigitta Sipocz https://github.com/bsipocz

Package Contributors
--------------------
* Alex Conley
* Andreas Kopecky
* Andrew Connolly
* Asif Imran
* Benjamin Alan Weaver
* Brigitta Sipocz
* Chris Desira
* Daniel Andreasen
* Dino Bektesevic
* Edward Betts
* Engineero
* Hans Moritz Günther
* Hugo van Kemenade
* Jake Vanderplas
* Jeremy Blow
* Jonathan Sick
* Joris
* Juanjo Bazán
* Julian Taylor
* Lars Buitinck
* Morgan Fouesneau
* Nicholas Hunt-Walker
* Rodrigo Nemmen
* Ross Fadely
* Vlad Skripniuk
* stonebig
